summaryrefslogtreecommitdiff
path: root/scripts/fixup_notices_rendered.php
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/fixup_notices_rendered.php')
-rwxr-xr-xscripts/fixup_notices_rendered.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/scripts/fixup_notices_rendered.php b/scripts/fixup_notices_rendered.php
index 3e7eb7acb..359cd6cce 100755
--- a/scripts/fixup_notices_rendered.php
+++ b/scripts/fixup_notices_rendered.php
@@ -1,8 +1,8 @@
#!/usr/bin/env php
<?php
/*
* Laconica - a distributed open-source microblogging tool
* Copyright (C) 2008, 2009, Control Yourself, Inc.
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
@@ -25,7 +25,8 @@ if (isset($_SERVER) && array_key_exists('REQUEST_METHOD', $_SERVER)) {
}
define('INSTALLDIR', realpath(dirname(__FILE__) . '/..'));
-define('LACONICA', true);
+define('STATUSNET', true);
+define('LACONICA', true); // compatibility
require_once(INSTALLDIR . '/lib/common.php');
@@ -1,8 +1,8 @@
<?php
/*
- * Laconica - a distributed open-source microblogging tool
- * Copyright (C) 2008, 2009, Control Yourself, Inc.
+ * StatusNet - the distributed open-source microblogging tool
+ * Copyright (C) 2008, 2009, StatusNet, Inc.
*
* This program is free software: you can redistribute it and/or modify